==> igniteui-angular-charts-18.0.0.tgz: package/esm5/lib/SlowStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { SlowStochasticOscillatorIndicatorStrategy } from "./SlowStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
var SlowStochasticOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SlowStochasticOscillatorIndicator, _super);
    function SlowStochasticOscillatorIndicator() {
        var _this = _super.call(this) || this;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 10;
        _this.trendLinePeriod = 3;
        return _this;
    }
    SlowStochasticOscillatorIndicator.prototype.bb = function () {
        return new SlowStochasticOscillatorIndicator();
    };
    SlowStochasticOscillatorIndicator.prototype.get_aaa = function () {
        return new SlowStochasticOscillatorIndicatorStrategy();
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "aaa", {
        get: function () {
            return this.get_aaa();
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.get_aan = function () {
        return SlowStochasticOscillatorIndicator.$;
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "aan", {
        get: function () {
            return this.get_aan();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "aav", {
        get: function () {
            return typeGetValue(this.c(SlowStochasticOscillatorIndicator.aaw));
        },
        set: function (a) {
            this.h(SlowStochasticOscillatorIndicator.aaw, a);
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.aag = function () {
        return this.aav;
    };
    SlowStochasticOscillatorIndicator.prototype.aap = function (a) {
        this.aav = a;
    };
    SlowStochasticOscillatorIndicator.$t = markType(SlowStochasticOscillatorIndicator, 'SlowStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    SlowStochasticOscillatorIndicator.aaw = StrategyBasedIndicator.aas(14, SlowStochasticOscillatorIndicator.$);
    return SlowStochasticOscillatorIndicator;
}(StrategyBasedIndicator));
export { SlowStochasticOscillatorIndicator };

==> igniteui-angular-charts-18.1.0.tgz: package/esm5/lib/SlowStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { SlowStochasticOscillatorIndicatorStrategy } from "./SlowStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
var SlowStochasticOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SlowStochasticOscillatorIndicator, _super);
    function SlowStochasticOscillatorIndicator() {
        var _this = _super.call(this) || this;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 10;
        _this.trendLinePeriod = 3;
        return _this;
    }
    SlowStochasticOscillatorIndicator.prototype.bi = function () {
        return new SlowStochasticOscillatorIndicator();
    };
    SlowStochasticOscillatorIndicator.prototype.get_abm = function () {
        return new SlowStochasticOscillatorIndicatorStrategy();
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "abm", {
        get: function () {
            return this.get_abm();
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.get_abz = function () {
        return SlowStochasticOscillatorIndicator.$;
    };
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "abz", {
        get: function () {
            return this.get_abz();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SlowStochasticOscillatorIndicator.prototype, "ab7", {
        get: function () {
            return typeGetValue(this.c(SlowStochasticOscillatorIndicator.ab8));
        },
        set: function (a) {
            this.h(SlowStochasticOscillatorIndicator.ab8, a);
        },
        enumerable: false,
        configurable: true
    });
    SlowStochasticOscillatorIndicator.prototype.abs = function () {
        return this.ab7;
    };
    SlowStochasticOscillatorIndicator.prototype.ab1 = function (a) {
        this.ab7 = a;
    };
    SlowStochasticOscillatorIndicator.$t = markType(SlowStochasticOscillatorIndicator, 'SlowStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    SlowStochasticOscillatorIndicator.ab8 = StrategyBasedIndicator.ab4(14, SlowStochasticOscillatorIndicator.$);
    return SlowStochasticOscillatorIndicator;
}(StrategyBasedIndicator));
export { SlowStochasticOscillatorIndicator };
